<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nombre_del_Programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Back</source>
        <translation>Atras</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>View Log</source>
        <translation>Ver registro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <location filename="../mainwindow.cpp" line="616"/>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Select ISO</source>
        <translation>Seleccione ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccione Dispositivo USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccione archivo ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Opciones avanzadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Crear el sistema de archivos ext4 incluso si existe uno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Guardar el directorio de arranque original al actualizar un live-usb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Use particionamiento gpt en lugar de msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>Particionamiento GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Actualizar (solamente actualiza un liveUSB existente)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>No reemplazar archivos syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Mantener archivos syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorar comprobacion USB/extraible</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Desactivar temporalmente el montaje automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Establecer el indicador de disco de arranque pmbr (no arrancará a través de UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>No use fuseiso para montar archivos iso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Tamaño de la partición ESP (uefi):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbosidad (de menos a más):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="506"/>
        <source>Data partition format type</source>
        <translation>Tipo de formato de partición de datos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Make separate data partition (percent)</source>
        <translation>Crear una partición de datos separada (porcentaje)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Refresh drive list</source>
        <translation>Refrescar lista de dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Show advanced options</source>
        <translation>Mostrar opciones avanzadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Modo completo: Li&amp;veUSB grabable</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Solo lectura, no se puede usar con persistencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>&amp;Modo imagen - sólo lectura LiveUSB (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="589"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Para distribuciones que no sean antiX/MX use el modo de imagen (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="637"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="675"/>
        <source>Percent of USB-device to use:</source>
        <translation>Porcentaje del dispositivo USB a usar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="682"/>
        <source>Label ext partition:</source>
        <translation>Etiqueta de partición ext:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="730"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>No ejecute comandos que afecten al dispositivo USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="733"/>
        <source>Dry run (no change to system)</source>
        <translation>Modo simulación (sin cambios en el sistema)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="740"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>clonar desde un archivo iso o live-usb montado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <source>Clone a mounted live system</source>
        <translation>Clonar un sistema en vivo montado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Configurado para arrancar desde una partición cifrada, solicitará una frase de contraseña en el primer arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Encrypt</source>
        <translation>Cifrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Clone running live system</source>
        <translation>Clonar sistema en vivo</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="vanished">Confirmación</translation>
    </message>
    <message>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation type="vanished">El dispositivo de destino %1 tiene más de %2 GB. ¿Desea continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="570"/>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>Failure</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>El origen y el destino están en el mismo dispositivo, seleccione nuevamente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <source>Source Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Could not find the source linuxfs file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Warning: The target device (%1) is smaller than the source (%2). The data might not fit. Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Size Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="151"/>
        <source>The target device %1 is larger than %2 GB.

This may indicate you have selected the wrong device.
Are you sure you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Large Target Device Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation>Escribiendo %1 usando el comando &apos;dd&apos; hacia /dev/%2,

Por favor, espere hasta que el proceso se complete</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>MX Live Usb Maker</source>
        <translation>MX Creador Live-Usb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Success</source>
        <translation>Exito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>LiveUSB creation successful!</source>
        <translation>¡Grabacion del Live-USB exitosa!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Error encontrado en el proceso de grabacion del Live-USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Please select a USB device to write to</source>
        <translation>Por favor seleccione el dispositivo USB para escribir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Estas acciones destruiran todos los datos en 

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Do you wish to continue?</source>
        <translation>¿Desea continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="534"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programa para grabar un live-usb a partir de un archivo iso, otro live-usb, un live-cd/dvd o un sistema en vivo en ejecución.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Seleccione un archivo ISO para grabar en la unidad USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="556"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>Archivos ISO (*.iso);;Todos los archivos (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Select Source Directory</source>
        <translation>Seleccionar directorio de origen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="570"/>
        <source>Could not find linuxfs file</source>
        <translation>No se pudo encontar el archivo linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Hide advanced options</source>
        <translation>Ocultar opciones avanzadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Select Source</source>
        <translation>Seleccione origen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Select ISO file</source>
        <translation>Seleccionar archivo ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="631"/>
        <source>clone</source>
        <translation>clonar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="698"/>
        <source>Could not find a log file at: </source>
        <translation>No se encontró un archivo de registro en: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <location filename="../about.cpp" line="85"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="99"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programa para grabar un live-usb a partir de un archivo iso, otro live-usb, un live-cd/dvd o un sistema en vivo en ejecución.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>filename</source>
        <translation>nombre de archivo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation>Nombre del archivo .iso para abrir</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>[filename]</source>
        <translation>[nombre de archivo]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que ha iniciado sesión como root, cierre la sesión e inicie sesión como usuario normal para usar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as root.</source>
        <translation>Debe ejecutar este programa como root.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>version:</source>
        <translation>versión:</translation>
    </message>
</context>
</TS>
